@@ -5,7 +5,7 @@ function(pb, value)
         control <- getOption("pboptions")
         rval <- switch(control$type, 
             txt = setTxtProgressBar(pb, value), 
-            tk = tcltk:::setTkProgressBar(pb, value, label=control$label))
+            tk = tcltk::setTkProgressBar(pb, value, label=control$label))
     } else rval <- NULL
     invisible(rval)
 }
