@@ -6,7 +6,7 @@ function(min=0, max=1)
         pb <- switch(control$type, 
             txt = txtProgressBar(min, max, initial=control$initial,
                 style = control$style, width = control$txt.width, char = control$char),
-            tk = tcltk:::tkProgressBar(min=min, max=max, initial=control$initial,
+            tk = tcltk::tkProgressBar(min=min, max=max, initial=control$initial,
                 title = control$title, label = control$label, width = control$gui.width))
     } else pb <- NULL
     invisible(pb)
